# Boyer-Moore-Algorithmus
Im Rahmen der Hausarbeit **Teilstring-basiertes Pattern Matching zur Erkennung von Phishing-URLs, _Untersuchung der Effektivität des Boyer-Moore-Algorithmus_** habe ich die C++-Implementierung des Boyer-Moore-Algorithmus von [Wikipedia](https://de.wikipedia.org/wiki/Boyer-Moore-Algorithmus) in Python portiert und um die Suche in `.txt` Dateien erweitert. Zur Effizienzsteigerung werden sowohl die Muster als auch der zu durchsuchende Text vorverarbeitet, bevor der eigentliche Vergleich beginnt.

Das Ziel dieser Implementierung ist es, mehrere Datensätze – bestehend aus Phishing- und legitimen URLs – zu durchlaufen und relevante Muster zu identifizieren. Die ermittelten Ergebnisse werden anschließend getrennt analysiert, interpretiert und visualisiert.


## How to use

<details><summary><b>Zeige Installation</b></summary>
